/*
===============================================================================

  FILE:  laszip_api_version.h

  CONTENTS:

    Version information for LASzip API interface

  PROGRAMMERS:

    martin.isenburg@rapidlasso.com  -  http://rapidlasso.com

  COPYRIGHT:

    (c) 2007-2017, martin isenburg, rapidlasso - fast tools to catch reality

    This is free software; you can redistribute and/or modify it under the
    terms of the GNU Lesser General Licence as published by the Free Software
    Foundation. See the COPYING file for more information.

    This software is distributed WITHOUT ANY WARRANTY and without even the
    implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

  CHANGE HISTORY:

    22 August 2017 -- Created

===============================================================================
*/

#ifndef LASZIP_API_VERSION_H
#define LASZIP_API_VERSION_H

/*
 * version settings
 */
#define LASZIP_API_VERSION_MAJOR 3
#define LASZIP_API_VERSION_MINOR 2
#define LASZIP_API_VERSION_PATCH 8

#define HAVE_UNORDERED_MAP 1

#endif /* LASZIP_API_VERSION_H */
